@@ -34,7 +34,7 @@ import gettext
 _ = lambda a: gettext.dgettext("ibus10", a)
 
 def get_version():
-	return '1.4.0'
+	return '1.4.1'
 
 def get_copyright():
     return _('''Copyright (c) 2007-2010 Peng Huang
@@ -45,10 +45,14 @@ def get_license():
 
 def get_ICON_KEYBOARD():
     import gtk
-    theme = gtk.icon_theme_get_default()
     icon = 'input-keyboard-symbolic'
+    fallback_icon = 'ibus-keyboard'
+    settings = gtk.settings_get_default()
+    if settings.get_property('gtk-icon-theme-name') != 'gnome':
+        return fallback_icon
+    theme = gtk.icon_theme_get_default()
     if not theme.lookup_icon(icon, 18, 0):
-        icon = 'ibus-keyboard'
+        return fallback_icon
     return icon
 
 ISOCODES_PREFIX='/usr/local'
